@@ -979,16 +979,6 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         logger.debug('ovs dpdk port data: %s' % data)
         self.interface_data[ovs_dpdk_port.name] = data
 
-        """Add an extra ifcfg entry for mellanox NICs,
-        for the interface which is a member of ovs_dpdk_port
-        with NM and DHCP disabled
-        """
-        if utils.is_mellanox_interface(ifname):
-            self.nm_controlled = False
-            self.use_dhcp = False
-            dpdk_if_name = objects.Interface(ifname)
-            self.add_interface(dpdk_if_name)
-
     def add_ovs_dpdk_bond(self, ovs_dpdk_bond):
         """Add an OvsDPDKBond object to the net config object.
 
@@ -1013,18 +1003,6 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         if ovs_dpdk_bond.rules:
             self._add_rules(ovs_dpdk_bond.name, ovs_dpdk_bond.rules)
 
-        """Add an extra ifcfg entry for mellanox NICs,
-        for all interfaces which is a member of ovs_dpdk_bond
-        with NM and DHCP disabled
-        """
-        for dpdk_port in ovs_dpdk_bond.members:
-            ifname = dpdk_port.members[0].name
-            if utils.is_mellanox_interface(ifname):
-                self.nm_controlled = False
-                self.use_dhcp = False
-                dpdk_if_name = objects.Interface(ifname)
-                self.add_interface(dpdk_if_name)
-
     def add_sriov_pf(self, sriov_pf):
         """Add a SriovPF object to the net config object
 
@@ -1036,7 +1014,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         utils.update_sriov_pf_map(sriov_pf.name, sriov_pf.numvfs,
                                   self.noop, promisc=sriov_pf.promisc,
                                   link_mode=sriov_pf.link_mode,
-                                  steering_mode=sriov_pf.steering_mode)
+                                  vdpa=sriov_pf.vdpa)
         self.interface_data[sriov_pf.name] = data
         if sriov_pf.routes:
             self._add_routes(sriov_pf.name, sriov_pf.routes)
@@ -1092,11 +1070,13 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         """
         logger.info('adding contrail_vrouter interface: %s'
                     % contrail_vrouter.name)
-        ifnames = ",".join([m.name for m in contrail_vrouter.members])
+        # Contrail vrouter will have the only member (of type interface,
+        # vlan or linux_bond)
+        ifname = contrail_vrouter.members[0].name
         data = self._add_common(contrail_vrouter)
         data += "DEVICETYPE=vhost\n"
         data += "TYPE=kernel_mode\n"
-        data += "BIND_INT=%s\n" % ifnames
+        data += "BIND_INT=%s\n" % ifname
         logger.debug('contrail data: %s' % data)
         self.interface_data[contrail_vrouter.name] = data
         if contrail_vrouter.routes:
@@ -1146,12 +1126,6 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         data = self._add_common(linux_tap)
         data += "TYPE=Tap\n"
         self.interface_data[linux_tap.name] = data
-        if linux_tap.routes:
-            self._add_routes(linux_tap.name,
-                             linux_tap.routes)
-        if linux_tap.rules:
-            self._add_rules(linux_tap.name,
-                            linux_tap.rules)
 
     def generate_ivs_config(self, ivs_uplinks, ivs_interfaces):
         """Generate configuration content for ivs."""
