@@ -1019,9 +1019,9 @@ class LinuxBond(_BaseOpts):
                         % (iface.device, iface.vfid))
             iface.trust = 'on'
         if iface.spoofcheck is None:
-            logger.info("Spoofcheck is not set for VF %s:%d, defaulting to off"
+            logger.info("Spoofcheck is not set for VF %s:%d, defaulting to on"
                         % (iface.device, iface.vfid))
-            iface.spoofcheck = 'off'
+            iface.spoofcheck = 'on'
         if iface.promisc is None:
             logger.info("Promisc is not set for VF %s:%d, defaulting to off"
                         % (iface.device, iface.vfid))
@@ -1033,8 +1033,7 @@ class LinuxBond(_BaseOpts):
                                   macaddr=iface.macaddr, promisc=iface.promisc,
                                   pci_address=iface.pci_address,
                                   min_tx_rate=iface.min_tx_rate,
-                                  max_tx_rate=iface.max_tx_rate,
-                                  driver=None)
+                                  max_tx_rate=iface.max_tx_rate)
 
     @staticmethod
     def from_json(json):
@@ -1120,8 +1119,7 @@ class OvsBond(_BaseOpts):
                                   trust=iface.trust, state=iface.state,
                                   macaddr=iface.macaddr, promisc=iface.promisc,
                                   min_tx_rate=iface.min_tx_rate,
-                                  max_tx_rate=iface.max_tx_rate,
-                                  driver=None)
+                                  max_tx_rate=iface.max_tx_rate)
 
     @staticmethod
     def from_json(json):
@@ -1330,7 +1328,7 @@ class OvsDpdkPort(_BaseOpts):
         self.rx_queue = rx_queue
 
     @staticmethod
-    def update_vf_config(iface, driver=None):
+    def update_vf_config(iface):
         if iface.trust is None:
             logger.info("Trust is not set for VF %s:%d, defaulting to on"
                         % (iface.device, iface.vfid))
@@ -1342,7 +1340,6 @@ class OvsDpdkPort(_BaseOpts):
         if iface.promisc is not None:
             logger.warning("Promisc can't be changed for ovs_dpdk_port")
             iface.promisc = None
-        logger.info("Overriding the default driver for DPDK")
         utils.update_sriov_vf_map(iface.device, iface.vfid, iface.name,
                                   vlan_id=iface.vlan_id, qos=iface.qos,
                                   spoofcheck=iface.spoofcheck,
@@ -1350,8 +1347,7 @@ class OvsDpdkPort(_BaseOpts):
                                   macaddr=iface.macaddr, promisc=iface.promisc,
                                   pci_address=iface.pci_address,
                                   min_tx_rate=iface.min_tx_rate,
-                                  max_tx_rate=iface.max_tx_rate,
-                                  driver=driver)
+                                  max_tx_rate=iface.max_tx_rate)
 
     @staticmethod
     def from_json(json):
@@ -1383,7 +1379,7 @@ class OvsDpdkPort(_BaseOpts):
                         # be set in the interface part of DPDK Port
                         members.append(iface)
                     elif isinstance(iface, SriovVF):
-                        OvsDpdkPort.update_vf_config(iface, driver)
+                        OvsDpdkPort.update_vf_config(iface)
                         members.append(iface)
                     else:
                         msg = 'Unsupported OVS DPDK Port member type'
@@ -1457,8 +1453,6 @@ class SriovVF(_BaseOpts):
         self.macaddr = macaddr
         self.promisc = promisc
         self.pci_address = pci_address
-        self.driver = None
-
         utils.update_sriov_vf_map(device, self.vfid, name,
                                   vlan_id=self.vlan_id,
                                   qos=self.qos,
@@ -1469,8 +1463,7 @@ class SriovVF(_BaseOpts):
                                   promisc=promisc,
                                   pci_address=pci_address,
                                   min_tx_rate=min_tx_rate,
-                                  max_tx_rate=max_tx_rate,
-                                  driver=self.driver)
+                                  max_tx_rate=max_tx_rate)
 
     @staticmethod
     def get_on_off(config):
@@ -1523,7 +1516,7 @@ class SriovPF(_BaseOpts):
                  defroute=True, dhclient_args=None, dns_servers=None,
                  nm_controlled=False, onboot=True, domain=None, members=None,
                  promisc=None, link_mode='legacy', ethtool_opts=None,
-                 steering_mode=None):
+                 vdpa=False):
         addresses = addresses or []
         routes = routes or []
         rules = rules or []
@@ -1542,7 +1535,7 @@ class SriovPF(_BaseOpts):
         self.promisc = promisc
         self.link_mode = link_mode
         self.ethtool_opts = ethtool_opts
-        self.steering_mode = steering_mode
+        self.vdpa = vdpa
 
     @staticmethod
     def get_on_off(config):
@@ -1562,17 +1555,24 @@ class SriovPF(_BaseOpts):
         promisc = SriovPF.get_on_off(promisc)
         link_mode = json.get('link_mode', 'legacy')
         ethtool_opts = json.get('ethtool_opts', None)
-        steering_mode = json.get('steering_mode')
-        if steering_mode is not None and steering_mode not in ['smfs', 'dmfs']:
-            msg = 'Expecting steering_mode to match smfs/dmfs'
-            raise InvalidConfigException(msg)
+        vdpa = json.get('vdpa', False)
+        if vdpa:
+            msg = ""
+            if link_mode != 'switchdev':
+                msg += "Expecting link_mode to be switchdev when vdpa is "\
+                       f"enabled, not {link_mode}\n"
+            if not int(numvfs):
+                msg += ("Expecting to have at least 1 numvfs when vdpa is "
+                        "enabled\n")
+            if len(msg):
+                raise InvalidConfigException(msg)
         if link_mode not in ['legacy', 'switchdev']:
             msg = 'Expecting link_mode to match legacy/switchdev'
             raise InvalidConfigException(msg)
         opts = _BaseOpts.base_opts_from_json(json)
         return SriovPF(name, numvfs, *opts, promisc=promisc,
                        link_mode=link_mode, ethtool_opts=ethtool_opts,
-                       steering_mode=steering_mode)
+                       vdpa=vdpa)
 
 
 class OvsDpdkBond(_BaseOpts):
